@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.8.0+   2011/01/21
+ * Version: 1.8.1   2011/04/01
  */
 
 #include "internal.h"
@@ -358,7 +358,7 @@ static bool ccs_same_path_acl(const struct ccs_acl_info *a,
  *
  * @a:         Pointer to "struct ccs_acl_info".
  * @b:         Pointer to "struct ccs_acl_info".
- * @is_delete: True for @a &= ~@b, false for @a |= @b. 
+ * @is_delete: True for @a &= ~@b, false for @a |= @b.
  *
  * Returns true if @a is empty, false otherwise.
  */
@@ -427,7 +427,7 @@ static bool ccs_same_mkdev_acl(const struct ccs_acl_info *a,
  *
  * @a:         Pointer to "struct ccs_acl_info".
  * @b:         Pointer to "struct ccs_acl_info".
- * @is_delete: True for @a &= ~@b, false for @a |= @b. 
+ * @is_delete: True for @a &= ~@b, false for @a |= @b.
  *
  * Returns true if @a is empty, false otherwise.
  */
@@ -500,7 +500,7 @@ static bool ccs_same_path2_acl(const struct ccs_acl_info *a,
  *
  * @a:         Pointer to "struct ccs_acl_info".
  * @b:         Pointer to "struct ccs_acl_info".
- * @is_delete: True for @a &= ~@b, false for @a |= @b. 
+ * @is_delete: True for @a &= ~@b, false for @a |= @b.
  *
  * Returns true if @a is empty, false otherwise.
  */
@@ -708,7 +708,7 @@ static int __ccs_open_permission(struct dentry *dentry, struct vfsmount *mnt,
 	idx = ccs_read_lock();
 	if (acc_mode && ccs_init_request_info(&r, CCS_MAC_FILE_OPEN)
 	    != CCS_CONFIG_DISABLED) {
-		if (!buf.name && !ccs_get_realpath(&buf, dentry, mnt)) {
+		if (!ccs_get_realpath(&buf, dentry, mnt)) {
 			error = -ENOMEM;
 			goto out;
 		}
@@ -970,7 +970,7 @@ static bool ccs_same_path_number_acl(const struct ccs_acl_info *a,
  *
  * @a:         Pointer to "struct ccs_acl_info".
  * @b:         Pointer to "struct ccs_acl_info".
- * @is_delete: True for @a &= ~@b, false for @a |= @b. 
+ * @is_delete: True for @a &= ~@b, false for @a |= @b.
  *
  * Returns true if @a is empty, false otherwise.
  */
@@ -1135,7 +1135,7 @@ static int __ccs_chown_permission(struct dentry *dentry,
  * @file: Pointer to "struct file".
  * @cmd:  Command number.
  * @arg:  Value for @cmd.
- * 
+ *
  * Returns 0 on success, negative value otherwise.
  */
 static int __ccs_fcntl_permission(struct file *file, unsigned int cmd,
