@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.8.0+   2011/01/21
+ * Version: 1.8.1   2011/04/01
  */
 
 #include "internal.h"
@@ -432,6 +432,7 @@ void __init ccs_mm_init(void)
 	idx = ccs_read_lock();
 	if (ccs_find_domain(CCS_ROOT_NAME) != &ccs_kernel_domain)
 		panic("Can't register ccs_kernel_domain");
+#ifdef CONFIG_CCSECURITY_BUILTIN_INITIALIZERS
 	{
 		/* Load built-in policy. */
 		static char ccs_builtin_initializers[] __initdata
@@ -447,5 +448,6 @@ void __init ccs_mm_init(void)
 			cp = cp2;
 		}
 	}
+#endif
 	ccs_read_unlock(idx);
 }
